import time
import cherrypy
import gensim
import json
	  
class Word2VecService(object):
    """
    A small wrapper to speed-up working with term embeddings.
    Embeddings are loaded once in the constructor and
    can then be accessed quickly via a REST interface.
    """
    
    def __init__(self):
        print('Loading word2vec vectors...')
        start = time.time()
        self.vectors = gensim.models.KeyedVectors.load_word2vec_format('GoogleNews-vectors-negative300.bin.gz',
                                                                       binary=True)
        end = time.time()
        print('Loading word2vec vectors took: %.2f' %(end-start))
        
    def get(self, tokens):
        result = {}
        for t in tokens:
            try:
                v = self.vectors[t].tolist()
            except:
                v = None
            result[t] = v
        return json.dumps(result)

    # method 'get' is served publicly via REST
    get.exposed = True


    
# main method: starts the service.
if __name__ == "__main__":
    cherrypy.config.update({'server.socket_port': 8087})
    cherrypy.quickstart(Word2VecService())
